=====
Django UF Request
=====

Django UF Request is a simple method to request UF values

Quick start
-----------

1. Add "django_uf_request" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'django_uf_request',
    ]

Example usage
-------------

```html

```